#
# spec file for package clewarecontrol
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%if 0%{?suse_version} >= 1230
  %bcond_without systemd
%else
  %bcond_with systemd
%endif

%define clewareuser  _clewarecontrol
%define clewaregroup _clewarecontrol

Name:           clewarecontrol
Summary:        Control Cleware USB devices
%if 0%{?suse_version} < 1120
Version:        2.8
%endif
%if 0%{?suse_version} >= 1120
Version:        4.4
BuildRequires:  libhidapi-devel
%endif
Requires(pre):  shadow
BuildRequires:  gcc-c++
BuildRequires:  pkg-config
BuildRequires:  nagios-rpm-macros
%if %{with systemd}
BuildRequires: systemd-rpm-macros
%{?systemd_requires}
%else
Requires(pre):  %insserv_prereq
%endif
Url:            http://www.vanheusden.com/clewarecontrol/
Release:        1.1
License:        GPL-2.0
Group:          Hardware/Other
Patch0:         sequence-points.patch
Source:         %{name}-%{version}.tgz
Source1:        %{name}.service
Source2:        clewarecontrol.rc
Source3:        %{name}.conf
Source12:       check_temperature
Source100:      clewarecontrol-rpmlintrc
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This program lets you control the USB-devices made by Cleware GmbH.

You can measure the temperature or humidity, switch on and off and configure
switches, control the watchdog, etc.

%package    check_temperature
Summary:    Nagios script to monitor the temperature through clewarecontrol
Group:      System/Monitoring
Recommends: nrpe

%description check_temperature
Provides a small bash script which interacts with nagios or icinga through
NRPE.

%pre
/usr/sbin/groupadd -r %{clewaregroup} >/dev/null 2>&1 || :
/usr/sbin/useradd -g %{clewaregroup} -s /bin/false -r \
  -c "clewarecontrol" -d /var/run/clewarecontrol %{clewareuser} >/dev/null 2>&1 || :
%if %{with systemd}
  %service_add_pre %{name}.service
%endif

%post
%if %{with systemd}
  systemd-tmpfiles --create %{_tmpfilesdir}/%{name}.conf || true
  %service_add_post %{name}.service
%endif

%preun
%if %{with systemd}
  %service_del_preun %{name}.service
%else
  %stop_on_removal %{name}
%endif

%postun
%if %{with systemd}
  %service_del_postun %{name}.service
%else
  %restart_on_update %{name}
  %insserv_cleanup
%endif

%prep
%setup -q -n %{name}-%{version}
%patch0 -p1

%build
CXXFLAGS+=" $RPM_OPT_FLAGS"
export CXXFLAGS
make %{?_smp_mflags}

%install
mkdir -p %{buildroot}/%{_bindir} %{buildroot}%{_sbindir}
mkdir -p %{buildroot}%{_mandir}/man1
make install DESTDIR=%{buildroot} PREFIX=%{_prefix}
install -Dm 755 %{SOURCE12} %{buildroot}/%{nagios_plugindir}/check_temperature
%if %{with systemd}
  install -D -m 0644 %{S:1} \
    %{buildroot}%{_unitdir}/%{name}.service
  ln -sf %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}
  install -D -m 0644 %{S:3} %{buildroot}%{_tmpfilesdir}/%{name}.conf
%else
  install -D -m 0755 %{S:2} \
    %{buildroot}%{_sysconfdir}/init.d/%{name}
  ln -sf %{_sysconfdir}/init.d/%{name} %{buildroot}%{_sbindir}/rc%{name}
  install -dD %{buildroot}%{_var}/run/%{name}/
%endif

%files
%defattr(-,root,root)
%{_sbindir}/rc%{name}
%{_bindir}/%{name}
%if %{with systemd}
  %dir %{_tmpfilesdir}
  %{_tmpfilesdir}/%{name}.conf
  %{_unitdir}/%{name}.service
%else
  /etc/init.d/%{name}
  %dir %attr(750,%{clewareuser},%{clewaregroup}) %{_var}/run/clewarecontrol/
%endif
%{_mandir}/man1/clewarecontrol.1.gz
%doc readme.txt

%files check_temperature
%defattr(0755,root,root)
%dir %{nagios_libdir}
%dir %{nagios_plugindir}
%{nagios_plugindir}/check_temperature

%changelog
* Mon Sep 18 2017 lars@linux-schulserver.de
- release 4.4:
  + Resolved some USB-issues, fixes for python library,
    improved the on-line help.
- added files provided by jloehel:
  + check_temperature
  + clewarecontrol.confi
  + clewarecontrol.rc
  + clewarecontrol.service
- added clewarecontrol-rpmlintrc
* Wed Jul 27 2016 jloehel@suse.com
- release 4.3
  Binary packages.
- Bugfixes release 4.1
  Fixes for hidapi handling. This may solve connectivity problems. Especially
  on macos x this was a problem.
* Fri Nov 13 2015 sndirsch@suse.com
- ran 'osc service localrun format_spec_file' in order to add a
  license header and cleanup the spec file;  removed unneeded
  %%clean section
* Wed Sep 23 2015 bhertwig@suse.com
-Added patch sequence-points.patch, which takes sequence points
  in C in consideration.
* Wed Sep 23 2015 bhertwig@suse.com
-Added patch which changes a few lines USBaccess.cpp to ensure correct building of the package on SLE11 based machines.
* Tue Sep 22 2015 bhertwig@suse.com
-A few changes to USBaccess.cpp in the 2.8 version, which
  prevented it from building on SLE_11 machines.
* Mon Sep 21 2015 bhertwig@suse.com
-Initial Release
